@@ -26,7 +26,9 @@
 #endif
 
 #include <ctype.h>
-#include <gnome.h>
+#include <string.h>
+
+#include <glib/gi18n.h>
 
 #include "gst.h"
 #include "callbacks.h"
@@ -124,7 +126,7 @@ boot_settings_gui_new (BootImage *image, GtkWidget *parent)
 
 	/* Image frame */
 	gui->image_frame = glade_xml_get_widget (gui->xml, "settings_image_frame");
-	gui->image_widget = glade_xml_get_widget (gui->xml, "settings_image");
+	gui->image_widget = GTK_ENTRY (glade_xml_get_widget (gui->xml, "settings_image"));
 	gui->root = glade_xml_get_widget (gui->xml, "settings_root");
 	gui->initrd_label = glade_xml_get_widget (gui->xml, "settings_initrd_label");
 	gui->initrd_widget = glade_xml_get_widget (gui->xml, "settings_initrd");
@@ -270,7 +272,6 @@ boot_settings_gui_setup (BootSettingsGui *gui, GtkWidget *top)
 {
 	BootImage *image = gui->image;
 	GList *type_list;
-	gchar *error;
 
 	if (image->type == TYPE_LINUX)
 	{
@@ -279,7 +280,7 @@ boot_settings_gui_setup (BootSettingsGui *gui, GtkWidget *top)
 		if (image->root)
 			gst_ui_entry_set_text (GTK_ENTRY (GTK_BIN (gui->root)->child), image->root);
 
-		if (error = boot_image_valid_initrd (image))
+		if (boot_image_valid_initrd (image))
 			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (gui->initrd_widget), "/boot");
 		else
 			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (gui->initrd_widget), image->initrd);
@@ -294,7 +295,7 @@ boot_settings_gui_setup (BootSettingsGui *gui, GtkWidget *top)
 		if (image->root)
 			gst_ui_entry_set_text (GTK_ENTRY (GTK_BIN (gui->root)->child), image->root);
 
-		if (error = boot_image_valid_module (image))
+		if (boot_image_valid_module (image))
 			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (gui->initrd_widget), "/boot");
 		else
 			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (gui->initrd_widget), image->module);
@@ -315,7 +316,7 @@ boot_settings_gui_setup (BootSettingsGui *gui, GtkWidget *top)
 	
 	gst_ui_entry_set_text (gui->name, image->label);
 
-	if (error = boot_image_valid_root (image) || !image->image)
+	if (boot_image_valid_root (image) || !image->image)
 		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (gui->image_widget), "/boot");
 	else
 		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (gui->image_widget), image->image);
@@ -403,7 +404,7 @@ boot_settings_gui_save (BootSettingsGui *gui, gboolean check)
 
 		if ((!msg_error) && (strcmp (gtk_entry_get_text (gui->password),
 					     gtk_entry_get_text (gui->password_confirm)) != 0))
-			msg_error = g_strdup (_("Password confirmation is not correct"));
+			msg_error = g_strdup (_("Password confirmation is not correct."));
 
 		if (msg_error) {
 			boot_settings_gui_error (GTK_WINDOW (gui->top), msg_error);
