@@ -21,8 +21,9 @@
 
 #include <config.h>
 
-#include <gnome.h>
 #include <gmodule.h>
+#include <glib/gi18n.h>
+#include <gdk/gdkkeysyms.h>
 #include "gst-widget.h"
 #include "gst-dialog.h"
 #include "gst-conf.h"
@@ -444,10 +445,11 @@ help_cb (GtkWidget *w, gpointer data)
 	gst_tool_show_help (gst_dialog->tool, NULL);
 }
 
-static void
+static gboolean
 dialog_delete_event_cb (GtkWidget *w, GdkEvent *event, gpointer data)
 {
 	cancel_cb (w, data);
+	return TRUE;
 }
 
 static gboolean
@@ -561,7 +563,7 @@ gst_dialog_construct (GstDialog *dialog, GstTool *tool,
 
 	g_signal_connect (G_OBJECT (dialog), "delete_event", G_CALLBACK (dialog_delete_event_cb), dialog);
 	g_signal_connect (G_OBJECT (tool->remote_dialog), "delete_event", G_CALLBACK (dialog_delete_event_cb), dialog);
-	g_signal_connect (G_OBJECT (dialog), "key-press-event", G_CALLBACK (dialog_key_press_event_cb), dialog);
+	g_signal_connect_after (G_OBJECT (dialog), "key-press-event", G_CALLBACK (dialog_key_press_event_cb), dialog);
 }
 
 GstDialog *
